<?php
/**
 * Plugin Name: Jos Oss Menu
 * Plugin URI: http://www.jososs.nl
 * Description: This plugin shows the page breadcrumbs in menu style
 * Version: 0.5.1 (first digit 0 means test phase)
 * Author: Jos van Oort
 * Author URI: http://www.josvanoort.nl
 * License: GPL2
 */
function jososs_menu_add_includes() {
	wp_enqueue_script("jososs_menu_css", WP_PLUGIN_URL . "/jososs-menu/includes/css/jososs-menu.css");
	wp_enqueue_script("jososs_menu_js" , WP_PLUGIN_URL . "/jososs-menu/includes/js/jososs-menu.js"  );
}
function jososs_menu_split_line(&$line_value, $walk_key, $page_title) {
	$line_value  =    trim($line_value);
	$pos_gt1     = stripos($line_value, ">"         , 0                      );
	$pos_pid     = stripos($line_value, "page_id="  , $pos_gt1               );
	$pos_gt2     = stripos($line_value, ">"         , $pos_pid               );
	$child_id    =  substr($line_value, $pos_pid + 8, $pos_gt2 - $pos_pid - 9);
	$child_title =  substr($line_value, $pos_gt2 + 1, -4                     );
	$line_title  = "{$page_title} - {$child_title}";
	$line_value  = "";
	$line_value .= "\t\t<option value=\"{$child_id}\" title=\"{$line_title}\">";
	$line_value .= $child_title;
	$line_value .= "</option>\n";
}
function jososs_menu_sanitize_line($sanitize_page_id) {
	if ($sanitize_page_id == 0) {$sanitize_page_title = "Home";}
	else                        {$sanitize_page_title = get_the_title($sanitize_page_id);}
	$sanitize_page_childs = wp_list_pages(array("child_of" => $sanitize_page_id, "echo" => 0, "depth" => 1, "title_li" => ""));
	$sanitize_page_childs = str_ireplace(array("<LI", "LI>"), array("<li", "li>"), $sanitize_page_childs);
	$sanitize_page_childs = explode("</li>", $sanitize_page_childs);
	array_pop($sanitize_page_childs);
	$sanitize_output = "";
	if (count ($sanitize_page_childs) > 0) {
		array_walk($sanitize_page_childs, "jososs_menu_split_line", $sanitize_page_title);
		$sanitize_output .= "\t<select id=\"menu{$sanitize_page_id}\" onchange=\"jososs_menu_show_page(this.id);\">\n";
		$sanitize_output .= "\t\t<option value=\"0\">&lt;{$sanitize_page_title}&gt;</option>\n";
		$sanitize_output .= implode("", $sanitize_page_childs);
		$sanitize_output .= "\t</select>\n";
	}
	return $sanitize_output;
}
function jososs_menu_create_content($current_page_id) {
	$current_page_childs = jososs_menu_sanitize_line($current_page_id);
	$return = $current_page_childs;
	do {
		$parent_page_id     = wp_get_post_parent_id($current_page_id);
		$parent_page_childs = jososs_menu_sanitize_line($parent_page_id);
		$current_page_id    = $parent_page_id;
		$return = "{$parent_page_childs}{$return}";
	} while($current_page_id > 0);
	return $return;
}
function jososs_menu_post_action($post_object) {
	$menu_content = jososs_menu_create_content($post_object->ID);
	echo "\n<div class=\"jososs_menu_post_top\">\n{$menu_content}</div>\n";
}
add_action("wp_head" , "jososs_menu_add_includes");
add_action("the_post", "jososs_menu_post_action" );

/* ------------------------------------ */
/* adding the plugin admin options page */
/* ------------------------------------ */

// add the admin options page
add_action('admin_menu', 'plugin_admin_add_page');
function plugin_admin_add_page() {
	add_options_page('Jos Oss Menu', 'Jos Oss Menu', 'manage_options', 'jososs-menu', 'plugin_options_page');
}

// display the admin options page
function plugin_options_page() {
?>
<div>
<h2>Instellingen voor plugin &ldquo;Jos Oss Menu&rdquo;</h2>
<small>uitleg over opties hier</small>
<form action="options.php" method="post">
<?php settings_fields('plugin_options'); ?>
<?php do_settings_sections('jososs-menu'); ?>
 
<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
</form></div>
 
<?php
}

// add the admin settings and such
add_action('admin_init', 'plugin_admin_init');

// function callback to display the guts of the section itself
function plugin_section_text() {
	echo '<small>uitleg over dit gedeelte hier</small>';
}

// function callback to display the input box
function plugin_setting_string() {
	$options = get_option('plugin_options');
	echo "<input id='plugin_text_string' name='plugin_options[text_string]' size='40' type='text' value='{$options['text_string']}' />";
}

// validate our options
function plugin_options_validate($input) {
	$options = get_option('plugin_options');
	$options['text_string'] = trim($input['text_string']);
	if(!preg_match('/^[a-z0-9]{32}$/i', $options['text_string'])) {
		$options['text_string'] = '';
	}
	return $options;
}

function plugin_admin_init(){
	register_setting    ('plugin_options'    , 'plugin_options'   , 'plugin_options_validate'                              );
	add_settings_section('plugin_main'       , 'Alle instellingen', 'plugin_section_text'    , 'jososs-menu'               );
	add_settings_field  ('plugin_text_string', 'Kleur van de knop', 'plugin_setting_string'  , 'jososs-menu', 'plugin_main');
}
